"use strict";
require("express-gateway");
const config_1 = require("./config");
const db_1 = require("./config/db");
const auth_secure_policy_1 = require("./policies/auth-secure-policy");
const basic_auth_policy_1 = require("./policies/basic-auth-policy");
const jwt_auth_policy_1 = require("./policies/jwt-auth-policy");
const local_auth_policy_1 = require("./policies/local-auth-policy");
const session_auth_policy_1 = require("./policies/session-auth-policy");
const auth_eg_1 = require("./routes/auth-eg");
const auth_user_eg_1 = require("./routes/auth-user-eg");
const google_oauth20_eg_1 = require("./routes/google-oauth20-eg");
const plugin = {
    version: '1.3.0',
    init: pluginContext => {
        config_1.initConfig(pluginContext.settings);
        db_1.initDatabase();
        pluginContext.registerPolicy(auth_secure_policy_1.default);
        pluginContext.registerPolicy(jwt_auth_policy_1.default);
        pluginContext.registerPolicy(basic_auth_policy_1.default);
        pluginContext.registerPolicy(local_auth_policy_1.default);
        pluginContext.registerPolicy(session_auth_policy_1.default);
        pluginContext.registerGatewayRoute(auth_eg_1.default);
        pluginContext.registerGatewayRoute(auth_user_eg_1.default);
        pluginContext.registerGatewayRoute(google_oauth20_eg_1.default);
    },
    policies: ['auth-secure', 'jwt-auth', 'session-auth', 'local-auth'],
    schema: {
        $id: 'http://express-gateway.io/schemas/plugin/express-gateway-plugin-cas.json',
        type: 'object',
        properties: {
            DATABASE_URL: {
                type: 'string'
            },
            AUTH_HEADER: {
                type: 'string'
            },
            ADMIN_KEY: {
                type: 'string'
            },
            JWT_SECRET: {
                type: 'string'
            },
            JWT_EXPIRATION_DELTA: {
                type: 'string'
            },
            JWT_REFRESH_EXPIRATION_DELTA: {
                type: 'string'
            }
        },
        required: ['DATABASE_URL']
    },
    options: {
        DATABASE_URL: {
            title: "User's database url",
            type: 'string',
            required: true
        }
    }
};
module.exports = plugin;
//# sourceMappingURL=manifest.js.map